==> ejc-accplat-api-3.0.0-20240105.073224-78-sources.jar: com/ejianc/business/accplat/originvoucher/vo/VoucherTemplateDetailVO.java <==
package com.ejianc.business.accplat.originvoucher.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 凭证模板明细
 * 
 * @author generator
 * 
 */
@ApiModel("凭证模板明细")
public class VoucherTemplateDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("模版ID")
    private Long voucherTemplateId;
    @ApiModelProperty("条件公式")
    private String conditionExpression;
    @ApiModelProperty("条件公式显示名称")
    private String conditionExpressionView;
    @ApiModelProperty("摘要标识input录入referUse常用billColumn单据字段")
    private String descriptionFlag;
    @ApiModelProperty("摘要表达式")
    private String descriptionExpression;
    @ApiModelProperty("摘要表达式显示名称")
    private String descriptionExpressionView;
    @ApiModelProperty("科目规则subject固定科目subjectContrast科目分类转化")
    private String subjectRuleFlag;
    @ApiModelProperty("科目规则-ID科目id或科目分类id")
    private Long subjectRuleId;
    @ApiModelProperty("科目规则编码-科目编码或科目分类编码")
    private String subjectRuleCode;
    @ApiModelProperty("科目规则名称-科目名称或科目分类名称")
    private String subjectRuleName;
    @ApiModelProperty("借贷方向debit借crebit贷")
    private String directionFlag;
    @ApiModelProperty("金额取值规则")
    private String mnyExpression;
    @ApiModelProperty("金额取值规则显示名称")
    private String mnyExpressionView;

    public String getDescriptionFlag() {
        return descriptionFlag;
    }

    public void setDescriptionFlag(String descriptionFlag) {
        this.descriptionFlag = descriptionFlag;
    }

    /**
     * 模版ID
     */
    public Long getVoucherTemplateId() {
        return voucherTemplateId;
    }

    /**
     * 模版ID
     */
    public void setVoucherTemplateId(Long voucherTemplateId) {
        this.voucherTemplateId = voucherTemplateId;
    }
    /**
     * 条件公式
     */
    public String getConditionExpression() {
        return conditionExpression;
    }

    /**
     * 条件公式
     */
    public void setConditionExpression(String conditionExpression) {
        this.conditionExpression = conditionExpression;
    }
    /**
     * 条件公式显示名称
     */
    public String getConditionExpressionView() {
        return conditionExpressionView;
    }

    /**
     * 条件公式显示名称
     */
    public void setConditionExpressionView(String conditionExpressionView) {
        this.conditionExpressionView = conditionExpressionView;
    }
    /**
     * 摘要表达式
     */
    public String getDescriptionExpression() {
        return descriptionExpression;
    }

    /**
     * 摘要表达式
     */
    public void setDescriptionExpression(String descriptionExpression) {
        this.descriptionExpression = descriptionExpression;
    }
    /**
     * 摘要表达式显示名称
     */
    public String getDescriptionExpressionView() {
        return descriptionExpressionView;
    }

    /**
     * 摘要表达式显示名称
     */
    public void setDescriptionExpressionView(String descriptionExpressionView) {
        this.descriptionExpressionView = descriptionExpressionView;
    }
    /**
     * 科目规则subject固定科目subjectContrast科目分类转化
     */
    public String getSubjectRuleFlag() {
        return subjectRuleFlag;
    }

    /**
     * 科目规则subject固定科目subjectContrast科目分类转化
     */
    public void setSubjectRuleFlag(String subjectRuleFlag) {
        this.subjectRuleFlag = subjectRuleFlag;
    }
    /**
     * 科目规则-ID科目id或科目分类id
     */
    public Long getSubjectRuleId() {
        return subjectRuleId;
    }

    /**
     * 科目规则-ID科目id或科目分类id
     */
    public void setSubjectRuleId(Long subjectRuleId) {
        this.subjectRuleId = subjectRuleId;
    }
    /**
     * 科目规则编码-科目编码或科目分类编码
     */
    public String getSubjectRuleCode() {
        return subjectRuleCode;
    }

    /**
     * 科目规则编码-科目编码或科目分类编码
     */
    public void setSubjectRuleCode(String subjectRuleCode) {
        this.subjectRuleCode = subjectRuleCode;
    }
    /**
     * 科目规则名称-科目名称或科目分类名称
     */
    public String getSubjectRuleName() {
        return subjectRuleName;
    }

    /**
     * 科目规则名称-科目名称或科目分类名称
     */
    public void setSubjectRuleName(String subjectRuleName) {
        this.subjectRuleName = subjectRuleName;
    }
    /**
     * 借贷方向debit借crebit贷
     */
    public String getDirectionFlag() {
        return directionFlag;
    }

    /**
     * 借贷方向debit借crebit贷
     */
    public void setDirectionFlag(String directionFlag) {
        this.directionFlag = directionFlag;
    }
    /**
     * 金额取值规则
     */
    public String getMnyExpression() {
        return mnyExpression;
    }

    /**
     * 金额取值规则
     */
    public void setMnyExpression(String mnyExpression) {
        this.mnyExpression = mnyExpression;
    }
    /**
     * 金额取值规则显示名称
     */
    public String getMnyExpressionView() {
        return mnyExpressionView;
    }

    /**
     * 金额取值规则显示名称
     */
    public void setMnyExpressionView(String mnyExpressionView) {
        this.mnyExpressionView = mnyExpressionView;
    }
    
}

==> ejc-accplat-api-3.0.0-20240112.091425-111-sources.jar: com/ejianc/business/accplat/originvoucher/vo/VoucherTemplateDetailVO.java <==
package com.ejianc.business.accplat.originvoucher.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 凭证模板明细
 * 
 * @author generator
 * 
 */
@ApiModel("凭证模板明细")
public class VoucherTemplateDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("模版ID")
    private Long voucherTemplateId;
    @ApiModelProperty("条件公式")
    private String conditionExpression;
    @ApiModelProperty("条件公式显示名称")
    private String conditionExpressionView;
    @ApiModelProperty("摘要标识input录入referUse常用billColumn单据字段")
    private String descriptionFlag;
    @ApiModelProperty("摘要表达式")
    private String descriptionExpression;
    @ApiModelProperty("摘要表达式显示名称")
    private String descriptionExpressionView;
    @ApiModelProperty("科目规则subject固定科目subjectContrast科目分类转化")
    private String subjectRuleFlag;
    @ApiModelProperty("科目规则-ID科目id或科目分类id")
    private Long subjectRuleId;
    @ApiModelProperty("科目规则编码-科目编码或科目分类编码")
    private String subjectRuleCode;
    @ApiModelProperty("科目规则名称-科目名称或科目分类名称")
    private String subjectRuleName;
    @ApiModelProperty("借贷方向debit借credit贷")
    private String directionFlag;
    @ApiModelProperty("金额取值规则")
    private String mnyExpression;
    @ApiModelProperty("金额取值规则显示名称")
    private String mnyExpressionView;

    public String getDescriptionFlag() {
        return descriptionFlag;
    }

    public void setDescriptionFlag(String descriptionFlag) {
        this.descriptionFlag = descriptionFlag;
    }

    /**
     * 模版ID
     */
    public Long getVoucherTemplateId() {
        return voucherTemplateId;
    }

    /**
     * 模版ID
     */
    public void setVoucherTemplateId(Long voucherTemplateId) {
        this.voucherTemplateId = voucherTemplateId;
    }
    /**
     * 条件公式
     */
    public String getConditionExpression() {
        return conditionExpression;
    }

    /**
     * 条件公式
     */
    public void setConditionExpression(String conditionExpression) {
        this.conditionExpression = conditionExpression;
    }
    /**
     * 条件公式显示名称
     */
    public String getConditionExpressionView() {
        return conditionExpressionView;
    }

    /**
     * 条件公式显示名称
     */
    public void setConditionExpressionView(String conditionExpressionView) {
        this.conditionExpressionView = conditionExpressionView;
    }
    /**
     * 摘要表达式
     */
    public String getDescriptionExpression() {
        return descriptionExpression;
    }

    /**
     * 摘要表达式
     */
    public void setDescriptionExpression(String descriptionExpression) {
        this.descriptionExpression = descriptionExpression;
    }
    /**
     * 摘要表达式显示名称
     */
    public String getDescriptionExpressionView() {
        return descriptionExpressionView;
    }

    /**
     * 摘要表达式显示名称
     */
    public void setDescriptionExpressionView(String descriptionExpressionView) {
        this.descriptionExpressionView = descriptionExpressionView;
    }
    /**
     * 科目规则subject固定科目subjectContrast科目分类转化
     */
    public String getSubjectRuleFlag() {
        return subjectRuleFlag;
    }

    /**
     * 科目规则subject固定科目subjectContrast科目分类转化
     */
    public void setSubjectRuleFlag(String subjectRuleFlag) {
        this.subjectRuleFlag = subjectRuleFlag;
    }
    /**
     * 科目规则-ID科目id或科目分类id
     */
    public Long getSubjectRuleId() {
        return subjectRuleId;
    }

    /**
     * 科目规则-ID科目id或科目分类id
     */
    public void setSubjectRuleId(Long subjectRuleId) {
        this.subjectRuleId = subjectRuleId;
    }
    /**
     * 科目规则编码-科目编码或科目分类编码
     */
    public String getSubjectRuleCode() {
        return subjectRuleCode;
    }

    /**
     * 科目规则编码-科目编码或科目分类编码
     */
    public void setSubjectRuleCode(String subjectRuleCode) {
        this.subjectRuleCode = subjectRuleCode;
    }
    /**
     * 科目规则名称-科目名称或科目分类名称
     */
    public String getSubjectRuleName() {
        return subjectRuleName;
    }

    /**
     * 科目规则名称-科目名称或科目分类名称
     */
    public void setSubjectRuleName(String subjectRuleName) {
        this.subjectRuleName = subjectRuleName;
    }
    /**
     * 借贷方向debit借credit贷
     */
    public String getDirectionFlag() {
        return directionFlag;
    }

    /**
     * 借贷方向debit借credit贷
     */
    public void setDirectionFlag(String directionFlag) {
        this.directionFlag = directionFlag;
    }
    /**
     * 金额取值规则
     */
    public String getMnyExpression() {
        return mnyExpression;
    }

    /**
     * 金额取值规则
     */
    public void setMnyExpression(String mnyExpression) {
        this.mnyExpression = mnyExpression;
    }
    /**
     * 金额取值规则显示名称
     */
    public String getMnyExpressionView() {
        return mnyExpressionView;
    }

    /**
     * 金额取值规则显示名称
     */
    public void setMnyExpressionView(String mnyExpressionView) {
        this.mnyExpressionView = mnyExpressionView;
    }
    
}
